@@ -486,7 +486,7 @@ def test_default_containers(ldap_base):
             f'cn=entry,cn=portals,cn=univention,{ldap_base}',
             f'cn=category,cn=portals,cn=univention,{ldap_base}',
             f'cn=folder,cn=portals,cn=univention,{ldap_base}',
-            f'cn=announcement,cn=portals,cn=univention,{ldap_base}'
+            f'cn=announcement,cn=portals,cn=univention,{ldap_base}',
         ],
         'groups/group': [f'cn=groups,{ldap_base}'],
         'dhcp/shared': [f'cn=dhcp,{ldap_base}'],
