@@ -11,7 +11,9 @@ import json
 import pytest
 import requests
 
-from dockertest import App, UCTTest_DockerApp_UMCInstallFailed, get_app_name
+from dockertest import (
+    App, UCSTest_DockerApp_VerifyFailed, UCTTest_DockerApp_UMCInstallFailed, error_handling_call, get_app_name,
+)
 
 
 URL = 'https://docker.software-univention.de/v2/ucs-appbox-amd64/tags/list'
@@ -97,6 +99,7 @@ def test_app_umc_install_latest_appbox(appcenter, data, image):
         appcenter.update()
         app.install_via_umc()
         app.verify()
+        error_handling_call(['docker', 'exec', app.container_id, 'univention-check-join-status'], exc=UCSTest_DockerApp_VerifyFailed)
     finally:
         app.uninstall()
         app.remove()
