@@ -129,7 +129,7 @@ def test_users(udm_module_scope, ldap_base, lo) -> Users:
 def logout(umc_browser_test: UMCBrowserTest):
     side_menu = SideMenu(umc_browser_test)
     side_menu.navigate(do_login=False)
-    side_menu.logout()
+    side_menu.logout_with_fallback()
 
 
 @pytest.mark.parametrize('role', ['admin', 'regular'])
@@ -245,7 +245,7 @@ def test_login_while_changing_password(admin_user: User, random_password: str, u
     password_expired_text: Locator = umc_browser_test.page.get_by_text(_('The password has expired and must be renewed.'))
     expect(password_expired_text).to_be_visible()
 
-    umc_browser_test.page.get_by_label(_('New password'), exact=True).type(random_password)
+    umc_browser_test.page.get_by_label(_('New password'), exact=True).press_sequentially(random_password)
     time.sleep(0.5)
 
     retype_input = umc_browser_test.page.get_by_label(_('New Password (retype)'))
