@@ -22,7 +22,7 @@ def test_suggestion_category_is_shown(umc_browser_test: UMCBrowserTest, app_cent
     "v1": [{
         "condition": [],
         "candidates": [{
-            "id": "owncloud",
+            "id": "univention-demo-data",
             "mayNotBeInstalled": []
         }]
     }]
