@@ -35,12 +35,16 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
+from typing import TYPE_CHECKING
 
 from playwright.sync_api import Locator, Page, expect
 
 from univention.config_registry import ucr
 from univention.lib.i18n import Translation
-from univention.testing.browser.lib import UMCBrowserTest
+
+
+if TYPE_CHECKING:
+    from univention.testing.browser.lib import UMCBrowserTest
 
 
 _ = Translation('ucs-test-framework').translate
@@ -123,7 +127,7 @@ class DetailsView:
         remove_button.click()
 
 
-class GenericUDMModule(object):
+class GenericUDMModule:
     """
     The GenericUmcModule is the base class for a bunch of UMC Modules which are all structured similarly
     This class provides a bunch of methods for functionality that is similar/common in the modules.
