@@ -34,10 +34,15 @@
 
 from __future__ import annotations
 
+from typing import TYPE_CHECKING
+
 from playwright.sync_api import Locator, Page, expect
 
 from univention.lib.i18n import Translation
-from univention.testing.browser.lib import UMCBrowserTest
+
+
+if TYPE_CHECKING:
+    from univention.testing.browser.lib import UMCBrowserTest
 
 
 _ = Translation('ucs-test-framework').translate
@@ -100,7 +105,7 @@ class UCSPortalEditMode:
         self.page.get_by_label(_('Internal name *')).fill(internal_name)
 
         self.fill_localization_dialog(name, 'Name')
-        self.page.get_by_role('button', name=_('Save')).click()
+        self.page.get_by_role('dialog', name='Add category').get_by_role('button', name='Save').click()
 
         expect(self.page.get_by_text(_('Category successfully added'))).to_be_visible()
 
@@ -117,7 +122,7 @@ class UCSPortalEditMode:
 
         self.page.locator('[data-test="localeInput--Links"]').fill(link)
 
-        self.page.get_by_role('button', name=_('Save')).click()
+        self.page.get_by_role('dialog', name='Create a new Entry').get_by_role('button', name='Save').click()
 
         expect(self.page.get_by_text(_('Entry successfully added'))).to_be_visible()
 
@@ -129,7 +134,7 @@ class UCSPortalEditMode:
         self.page.get_by_label(_('Internal name *')).fill(internal_name)
 
         self.fill_localization_dialog(name, 'Name')
-        self.page.get_by_role('button', name=_('Save')).click()
+        self.page.get_by_role('dialog', name='Create a new folder').get_by_role('button', name='Save').click()
 
         expect(self.page.get_by_text('Folder successfully added')).to_be_visible()
 
@@ -180,11 +185,11 @@ class UCSPortal:
         self.tester: UMCBrowserTest = tester
         self.page: Page = tester.page
 
-    def navigate(self, username='Administrator', password='univention', do_login: bool = True):
+    def navigate(self, username='Administrator', password='univention', do_login: bool = True, portal_url=None):
         if do_login:
             self.tester.login(username, password, location='/univention/portal')
         else:
-            self.page.goto(f'{self.tester.base_url}/univention/portal')
+            self.page.goto(f'{portal_url or self.tester.base_url}/univention/portal')
 
     def side_menu(self) -> UCSSideMenu:
         return UCSSideMenu(self.tester)
