@@ -283,7 +283,7 @@ def map_udm_user_to_con(user):
         "pagerTelephoneNumber": "pager",
         "sambaUserWorkstations": "userWorkstations"}
     # return {mapping[key]: value for (key, value) in user.items() if key in mapping}
-    return {mapping[key]: ([value] if not isinstance(value, (list, tuple)) else value) for (key, value) in user.items() if key in mapping}
+    return {mapping[key]: ([value] if not isinstance(value, list | tuple) else value) for (key, value) in user.items() if key in mapping}
 
 
 def map_udm_group_to_con(group):
@@ -295,7 +295,7 @@ def map_udm_group_to_con(group):
     """
     mapping = {"name": "sAMAccountName", "description": "description"}
     # return {mapping[key]: value for (key, value) in group.items() if key in mapping}
-    return {mapping[key]: ([value] if not isinstance(value, (list, tuple)) else value) for (key, value) in group.items() if key in mapping}
+    return {mapping[key]: ([value] if not isinstance(value, list | tuple) else value) for (key, value) in group.items() if key in mapping}
 
 
 def map_udm_windows_to_con(windows):
@@ -311,7 +311,7 @@ def map_udm_windows_to_con(windows):
         "operatingSystem": "operatingSystem",
         "operatingSystemVersion": "operatingSystemVersion",
     }
-    return {mapping[key]: ([value] if not isinstance(value, (list, tuple)) else value) for (key, value) in windows.items() if key in mapping}
+    return {mapping[key]: ([value] if not isinstance(value, list | tuple) else value) for (key, value) in windows.items() if key in mapping}
 
 
 def map_udm_container_to_con(container):
@@ -325,7 +325,7 @@ def map_udm_container_to_con(container):
         "name": "cn",
         "description": "description",
     }
-    return {mapping[key]: ([value] if not isinstance(value, (list, tuple)) else value) for (key, value) in container.items() if key in mapping}
+    return {mapping[key]: ([value] if not isinstance(value, list | tuple) else value) for (key, value) in container.items() if key in mapping}
 
 
 def map_udm_ou_to_con(container):
@@ -339,15 +339,13 @@ def map_udm_ou_to_con(container):
         "name": "ou",
         "description": "description",
     }
-    return {mapping[key]: ([value] if not isinstance(value, (list, tuple)) else value) for (key, value) in container.items() if key in mapping}
+    return {mapping[key]: ([value] if not isinstance(value, list | tuple) else value) for (key, value) in container.items() if key in mapping}
 
 
 def create_udm_user(udm, con, user, wait_for_sync, verify=True):
     print(f"\nCreating UDM user {user.basic}\n")
     (udm_user_dn, username) = udm.create_user(**user.to_unicode(user.basic))
-    con_user_dn = ldap.dn.dn2str([
-        [("CN", to_unicode(username), ldap.AVA_STRING)],
-        [("CN", "users", ldap.AVA_STRING)]] + ldap.dn.str2dn(con.adldapbase))
+    con_user_dn = ldap.dn.dn2str([[("CN", to_unicode(username), ldap.AVA_STRING)], [("CN", "users", ldap.AVA_STRING)], *ldap.dn.str2dn(con.adldapbase)])
     wait_for_sync()
     if verify:
         con.verify_object(con_user_dn, map_udm_user_to_con(user.basic))
@@ -361,16 +359,13 @@ def delete_udm_user(udm, con, udm_user_dn, con_user_dn, wait_for_sync):
     con.verify_object(con_user_dn, None)
 
 
-def create_con_user(con, udm_user, wait_for_sync, basic_con_user=None):
-    if not basic_con_user:
-        basic_con_user = map_udm_user_to_con(udm_user.basic)
+def create_con_user(con, udm_user, wait_for_sync):
+    basic_con_user = map_udm_user_to_con(udm_user.basic)
 
     print(f"\nCreating CON user {basic_con_user}\n")
     username = udm_user.basic.get("username")
     con_user_dn = con.createuser(username, **basic_con_user)
-    udm_user_dn = ldap.dn.dn2str([
-        [("uid", to_unicode(username), ldap.AVA_STRING)],
-        [("CN", "users", ldap.AVA_STRING)]] + ldap.dn.str2dn(configRegistry.get('ldap/base')))
+    udm_user_dn = ldap.dn.dn2str([[("uid", to_unicode(username), ldap.AVA_STRING)], [("CN", "users", ldap.AVA_STRING)], *ldap.dn.str2dn(configRegistry.get("ldap/base"))])
     wait_for_sync()
     verify_udm_object("users/user", udm_user_dn, udm_user.basic)
     return (basic_con_user, con_user_dn, udm_user_dn)
@@ -386,9 +381,7 @@ def delete_con_user(con, con_user_dn, udm_user_dn, wait_for_sync):
 def create_udm_group(udm, con, group, wait_for_sync):
     print(f"\nCreating UDM group {group}\n")
     (udm_group_dn, groupname) = udm.create_group(**group.to_unicode(group.group))
-    con_group_dn = ldap.dn.dn2str([
-        [("CN", to_unicode(groupname), ldap.AVA_STRING)],
-        [("CN", "groups", ldap.AVA_STRING)]] + ldap.dn.str2dn(con.adldapbase))
+    con_group_dn = ldap.dn.dn2str([[("CN", to_unicode(groupname), ldap.AVA_STRING)], [("CN", "groups", ldap.AVA_STRING)], *ldap.dn.str2dn(con.adldapbase)])
     wait_for_sync()
     con.verify_object(con_group_dn, map_udm_group_to_con(group.group))
     return (udm_group_dn, con_group_dn)
@@ -407,9 +400,7 @@ def create_con_group(con, udm_group, wait_for_sync):
     print(f"\nCreating CON group {con_group}\n")
     groupname = to_unicode(udm_group.group.get("name"))
     con_group_dn = con.group_create(groupname, **con_group)
-    udm_group_dn = ldap.dn.dn2str([
-        [("cn", groupname, ldap.AVA_STRING)],
-        [("CN", "groups", ldap.AVA_STRING)]] + ldap.dn.str2dn(configRegistry.get('ldap/base')))
+    udm_group_dn = ldap.dn.dn2str([[("cn", groupname, ldap.AVA_STRING)], [("CN", "groups", ldap.AVA_STRING)], *ldap.dn.str2dn(configRegistry.get("ldap/base"))])
     wait_for_sync()
     verify_udm_object("groups/group", udm_group_dn, udm_group.group)
     return (con_group, con_group_dn, udm_group_dn)
